<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const page = usePage();
const product = page.props.product;
const carMakes = computed(() => page.props.carMakes || []);
const carModels = computed(() => page.props.carModels || []);
const carBodyStyles = computed(() => page.props.carBodyStyles || []);

const flashMessage = ref('');
const years = generateYears(1949, new Date().getFullYear()); // Adjust the range as needed

const form = useForm({
    id: product.id,
    item_number: product.item_number,
    nags_description: product.nags_description,
    item_description: product.item_description,
    data_price: product.data_price,
    price_margin: product.price_margin,
    price: product.price,
    quantity: product.quantity,
    stock: product.stock,
    year: product.year,
    make: product.make,
    model: product.model,
    bodystyle: product.bodystyle,
});

// const productPrice = form.price;

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());

const productPrice = computed(() => calculatePrice());

const calculatePrice = () => {
    var price = form.price;
    if(form.price_margin) {
        price = parseFloat(form.data_price) + parseFloat(form.data_price * (form.price_margin / 100));
        price = price.toFixed(2);
    }
    return price;
};

const submit = () => {
    const productID = product.id;
    console.log(productID);
    form.post(route('admin.product.update',{id: productID}), {
        onSuccess: () => {
            flashMessage.value = "Product updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

onMounted(() => {
    calculatePrice();
});
</script>

<template>

    <Head title="Edit Product" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit Product</h2>
        </template>

        <div class="py-12">
            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit">

                    <div v-if="flashMessage" class="font-bold text-green-600">
                        <div class="form-row px-8">
                            <div class="col-md-6">
                                <h4>{{ flashMessage }}</h4>
                            </div>
                        </div>
                    </div>

                    <input type="hidden" id="id" v-model="form.id" />
                    <div class="form-row px-8">

                        <div class="mt-4 col-md-3">
                            <InputLabel for="item_number" value="Item Number" />

                            <TextInput
                                id="item_number"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.item_number"
                                required
                                autofocus
                                autocomplete="item_number"
                            />

                            <InputError class="mt-2" :message="form.errors.item_number" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="data_price" value="Price" />

                            <TextInput
                                id="data_price"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.data_price"
                                required
                                autofocus
                                autocomplete="data_price"
                            />

                            <InputError class="mt-2" :message="form.errors.data_price" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="price_percentage" value="Margin Percentage (%)" />

                            <TextInput
                                id="price_margin"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.price_margin"
                                required
                                autofocus
                                autocomplete="price_margin"
                            />

                            <InputError class="mt-2" :message="form.errors.price_margin" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="price" :value="`${form.price_margin}% of Price`" />

                            <TextInput
                                id="price"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="productPrice"
                                required
                                autofocus
                                autocomplete="price"
                            />

                            <InputError class="mt-2" :message="form.errors.price" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="quantity" value="Quantity" />

                            <TextInput
                                id="quantity"
                                type="number"
                                class="mt-1 block w-full"
                                v-model="form.quantity"
                                required
                                autofocus
                                autocomplete="quantity"
                            />

                            <InputError class="mt-2" :message="form.errors.quantity" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="stock" value="Stock" />

                            <select id="stock" class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.stock" required>
                                <option value="">Select</option>
                                <option value="1">In Stock</option>
                                <option value="2">Please Call</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.stock" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="year" value="Year" />
                            <select class="w-full mt-1 block border-gray-300 rounded-md" autofocus v-model="form.year" id="year" required multiple>
                                <option v-for="year in reversedYears" :key="year" :value="year" :selected="form.year.includes(year)">{{ year }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="make" value="Make" />
                            <select class="w-full mt-1 block border-gray-300 rounded-md" id="make" v-model="form.make" required multiple>
                                <option value="">Select Make</option>
                                <option v-for="carmake in carMakes" :key="carmake.id" :value="carmake.id" :selected="form.make.includes(carmake.id)">{{ carmake.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-md-2">
                            <InputLabel for="model" value="Model" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" id="make" v-model="form.model" required multiple>
                                <option value="">Select Model</option>
                                <option v-for="carmodel in carModels" :key="carmodel.id" :value="carmodel.id" :selected="form.model.includes(carmodel.id)">{{ carmodel.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.model" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="bodystyle" value="Body Style" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" id="make" v-model="form.bodystyle" required multiple>
                                <option value="">Select Body Style</option>
                                <option v-for="bodystyle in carBodyStyles" :key="bodystyle.id" :value="bodystyle.id" :selected="form.bodystyle.includes(bodystyle.id)">{{ bodystyle.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.bodystyle" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="nags_description" value="Nags Description" />

                            <textarea
                                id="nags_description"
                                v-model="form.nags_description"
                                class="mt-1 block w-full border-gray-300 rounded-md"
                                placeholder="Enter description here..."
                            ></textarea>

                            <InputError class="mt-2" :message="form.errors.nags_description" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="item_description" value="Description" />

                            <textarea
                                id="item_description"
                                v-model="form.item_description"
                                class="mt-1 block w-full border-gray-300 rounded-md"
                                placeholder="Enter description here..."
                            ></textarea>

                            <InputError class="mt-2" :message="form.errors.item_description" />
                        </div>

                    </div>

                    <div class="flex items-center justify-end mt-4">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Update Product
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
